# svg-timeline

A pure python library to create timeline plots.

This is the result of `examples/emmy_noether.py`:

![a timeline of Emmy Noether's life](https://github.com/TiDreyer/svg-timeline/raw/main/examples/emmy_noether.svg)
